import type { StrictUnion } from 'simplytyped'
import Fellow from 'fellow'
import { SearchOptions } from 'getrepos'
/** Collection of fellows */
export declare type Fellows = Set<Fellow>
/** Export the Fellow class we have imported and are using, such that consumers of this package and ensure they are interacting with the same singletons */
export { Fellow }
/** GitHub's response when an error occurs */
interface GitHubError {
	message: string
}
/**
 * GitHub's response to getting a repository
 * https://developer.github.com/v3/repos/#list-contributors
 */
export interface GitHubContributor {
	login: string
	id: number
	node_id: string
	avatar_url: string
	gravatar_id: string
	url: string
	html_url: string
	followers_url: string
	following_url: string
	gists_url: string
	starred_url: string
	subscriptions_url: string
	organizations_url: string
	repos_url: string
	events_url: string
	received_events_url: string
	type: string
	site_admin: boolean
	contributions: number
}
export declare type GitHubContributorsResponse = StrictUnion<
	GitHubError | Array<GitHubContributor>
>
/**
 * GitHub's response to getting a user
 * https://developer.github.com/v3/users/#get-a-single-user
 */
export interface GitHubProfile {
	login: string
	id: number
	node_id: string
	avatar_url: string
	gravatar_id: string
	url: string
	html_url: string
	followers_url: string
	following_url: string
	gists_url: string
	starred_url: string
	subscriptions_url: string
	organizations_url: string
	repos_url: string
	events_url: string
	received_events_url: string
	type: string
	site_admin: false
	name: string
	company: string
	blog: string
	location: string
	email: string
	hireable: boolean
	bio: string
	public_repos: number
	public_gists: number
	followers: number
	following: number
	created_at: string
	updated_at: string
}
export declare type GitHubProfileResponse = StrictUnion<
	GitHubError | GitHubProfile
>
/** Fetch the full profile information for a contributor */
export declare function getContributorProfile(
	url: string
): Promise<GitHubProfile>
/** Fetch contributors from a Repository's GitHub Contributor API */
export declare function getContributorsFromCommits(
	slug: string
): Promise<Fellows>
/** Fetch contributors from a repository's `package.json` file */
export declare function getContributorsFromPackage(
	slug: string
): Promise<Fellows>
/** Fetch contributors from a GitHub repository slug */
export declare function getContributorsFromRepo(slug: string): Promise<Fellows>
/** Fetch contributors from GitHub repository slugs (e.g. `bevry/getcontributors`) */
export declare function getContributorsFromRepos(
	slugs: Array<string>
): Promise<Fellows>
/** Fetch contributors for all repositories, within the GitHub organisations and usernames (e.g. `bevry`, `balupton`) */
export declare function getContributorsFromOrgs(
	orgs: Array<string>
): Promise<Fellows>
/** Fetch contributors for all repositories that match a certain search query */
export declare function getContributorsFromSearch(
	query: string,
	opts: SearchOptions
): Promise<Fellows>
//# sourceMappingURL=index.d.ts.map
